# SNOw and Water model Analysis and Visualization

[![GitHub version](https://badge.fury.io/gh/USDA-ARS-NWRC%2Fsnowav.svg)](https://badge.fury.io/gh/USDA-ARS-NWRC%2Fsnowav)

SNOw and Water model Analysis and Visualization was developed at the USDA
Agricultural Research Service (ARS) in Boise, ID. SNOWAV processes model
outputs from AWSM into basin and sub-basins formats that are meaningful for
water resource managers and scientists.

![image](https://raw.githubusercontent.com/USDA-ARS-NWRC/awsm/master/docs/_static/ModelSystemOverview_new.png)
